==> flatland-model-diagram-editor-0.21.0.tar.gz: flatland-model-diagram-editor-0.21.0/flatland/database/population/drawing/text_style_instances.py <==
"""
text_style_instances.py
"""

population = [
    # Used in model diagrams
    {'Name': 'p9body', 'Typeface': 'Palatino', 'Size': 9, 'Slant': 'normal', 'Weight': 'normal',
     'Color': 'black', 'Spacing': 1.3},

    {'Name': 'p12title', 'Typeface': 'Palatino', 'Size': 12, 'Slant': 'normal', 'Weight': 'bold', 'Color': 'black',
     'Spacing': 1.3},

    {'Name': 'p9italic', 'Typeface': 'Palatino', 'Size': 9, 'Slant': 'italic', 'Weight': 'normal',
     'Color': 'black', 'Spacing': 1.3},

    # Used in Frames
    {'Name': 'Corner Title Large', 'Typeface': 'Eurostile', 'Size': 14, 'Slant': 'normal', 'Weight': 'normal',
     'Color': 'black', 'Spacing': 1.3},

    {'Name': 'Corner Title Medium', 'Typeface': 'Eurostile', 'Size': 14, 'Slant': 'normal', 'Weight': 'normal',
     'Color': 'black', 'Spacing': 1.3},

    {'Name': 'Block Title Large', 'Typeface': 'Eurostile', 'Size': 11, 'Slant': 'normal', 'Weight': 'normal',
     'Color': 'block blue', 'Spacing': 1.3},

    {'Name': 'Block Title Medium', 'Typeface': 'Eurostile', 'Size': 11, 'Slant': 'normal', 'Weight': 'normal',
     'Color': 'block blue', 'Spacing': 1.3},

    {'Name': 'boilerplate', 'Typeface': 'Courier', 'Size': 9, 'Slant': 'normal', 'Weight': 'normal',
     'Color': 'black', 'Spacing': 1.3},

    {'Name': 'coordinate', 'Typeface': 'Courier', 'Size': 12, 'Slant': 'normal', 'Weight': 'normal',
     'Color': 'toyota red', 'Spacing': 1.3},

    {'Name': 'Footer Central', 'Typeface': 'Verdana', 'Size': 11, 'Slant': 'italic', 'Weight': 'normal',
     'Color': 'black', 'Spacing': 1.3},

    {'Name': 'Block Body Large', 'Typeface': 'Verdana', 'Size': 9, 'Slant': 'normal', 'Weight': 'normal',
     'Color': 'black', 'Spacing': 1.3},

    {'Name': 'Block Body Medium', 'Typeface': 'Verdana', 'Size': 9, 'Slant': 'normal', 'Weight': 'normal',
     'Color': 'black', 'Spacing': 1.3},
]

==> flatland-model-diagram-editor-1.2.0.tar.gz: flatland-model-diagram-editor-1.2.0/flatland/database/population/drawing/text_style_instances.py <==
"""
text_style_instances.py
"""

population = [
    # Used in model diagrams
    {'Name': 'p9body', 'Typeface': 'Palatino', 'Size': 9, 'Slant': 'normal', 'Weight': 'normal',
     'Color': 'black', 'Spacing': 1.3},

    {'Name': 'p12title', 'Typeface': 'Palatino', 'Size': 12, 'Slant': 'normal', 'Weight': 'bold', 'Color': 'black',
     'Spacing': 1.3},

    {'Name': 'p9italic', 'Typeface': 'Palatino', 'Size': 9, 'Slant': 'italic', 'Weight': 'normal',
     'Color': 'black', 'Spacing': 1.3},

    # Used in Frames
    {'Name': 'Corner Title Large', 'Typeface': 'Eurostile', 'Size': 14, 'Slant': 'normal', 'Weight': 'normal',
     'Color': 'black', 'Spacing': 1.3},

    {'Name': 'Corner Title Medium', 'Typeface': 'Eurostile', 'Size': 14, 'Slant': 'normal', 'Weight': 'normal',
     'Color': 'black', 'Spacing': 1.3},

    {'Name': 'Corner Title Small', 'Typeface': 'Eurostile', 'Size': 12, 'Slant': 'normal', 'Weight': 'normal',
     'Color': 'black', 'Spacing': 1.1},

    {'Name': 'Block Title Large', 'Typeface': 'Eurostile', 'Size': 11, 'Slant': 'normal', 'Weight': 'normal',
     'Color': 'block blue', 'Spacing': 1.3},

    {'Name': 'Block Title Medium', 'Typeface': 'Eurostile', 'Size': 11, 'Slant': 'normal', 'Weight': 'normal',
     'Color': 'block blue', 'Spacing': 1.3},

    {'Name': 'Block Title Small', 'Typeface': 'Eurostile', 'Size': 9, 'Slant': 'normal', 'Weight': 'normal',
     'Color': 'block blue', 'Spacing': 1.1},

    {'Name': 'boilerplate', 'Typeface': 'Courier', 'Size': 9, 'Slant': 'normal', 'Weight': 'normal',
     'Color': 'black', 'Spacing': 1.3},

    {'Name': 'coordinate', 'Typeface': 'Courier', 'Size': 12, 'Slant': 'normal', 'Weight': 'normal',
     'Color': 'toyota red', 'Spacing': 1.3},

    {'Name': 'Footer Central', 'Typeface': 'Verdana', 'Size': 11, 'Slant': 'italic', 'Weight': 'normal',
     'Color': 'black', 'Spacing': 1.3},

    {'Name': 'Block Body Large', 'Typeface': 'Verdana', 'Size': 9, 'Slant': 'normal', 'Weight': 'normal',
     'Color': 'black', 'Spacing': 1.3},

    {'Name': 'Block Body Medium', 'Typeface': 'Verdana', 'Size': 9, 'Slant': 'normal', 'Weight': 'normal',
     'Color': 'black', 'Spacing': 1.3},

    {'Name': 'Block Body Small', 'Typeface': 'Verdana', 'Size': 7, 'Slant': 'normal', 'Weight': 'normal',
     'Color': 'black', 'Spacing': 1.1},
]
